@@ -234,7 +234,8 @@ class feature_data_loader:
         """
         symbol_list = self.data['ts_code'].unique()
         columns = self.data.columns
-        for symbol in symbol_list:
+        for index,symbol in enumerate(symbol_list):
+            print("数据进度百分比:%s" % (index / len(symbol_list) * 100), end='\r', flush=True)
             symbol_data = pd.DataFrame(self.data[self.data['ts_code'] == symbol])
             symbol_data.reset_index(drop=True, inplace=True)
             for func in self.features_list:
